@@ -152,6 +152,9 @@ class Student(Base):
     lang_division_id = Column(ForeignKey('univer_lang_division.lang_division_id'))
     lang_division = relationship('LangDivision')
 
+    # Нуждается в общежитии
+    need_hostel = Column('students_need_hostel', Integer)
+
     @property
     def payment_info_ru(self):
         if self.payment_form_id == 2:
